Learn R Programming

ghclass (version 0.1.0)

repo_add_badge: Add a GitHub Actions badge

Description

Add a GitHub Actions badge

Usage

repo_add_badge(
  repo,
  workflow = NULL,
  where = "^.",
  line_padding = "\n\n\n",
  file = "README.md"
)

Arguments

repo

Character. Address of repository in owner/name format.

workflow

Character. Name of the workflow located in .github/workflows/.

where

Character. Regex pattern of where to insert the badge, defaults to the beginning of the README

line_padding

Character. What should be added to the end of the link, defaults to sufficient new lines to add a blank line after the badge.

file

Character. Target file to be modified, defaults to README.md.