powered by
repo_commits returns a tibble of repositories belonging to a GitHub organization along with some basic statistics about those repositories.
repo_commits
repo_commits( repo, branch = "master", sha = branch, path = NULL, author = NULL, since = NULL, until = NULL, quiet = FALSE )
Character. Address of repository in owner/name format.
owner/name
Character. Branch to list commits from.
Character. SHA to start listing commits from.
Character. Only commits containing this file path will be returned.
Character. GitHub login or email address by which to filter commit author.
Character. Only commits after this date will be returned, expects YYYY-MM-DDTHH:MM:SSZ format.
YYYY-MM-DDTHH:MM:SSZ
Character. Only commits before this date will be returned, expects YYYY-MM-DDTHH:MM:SSZ format.
Logical. Should an error message be printed if the repo does not exist. Character.
# NOT RUN { org_repo_stats("ghclass") # } # NOT RUN { # }
Run the code above in your browser using DataLab