powered by
repo_contributors Returns a data frame containing statistics on contributor(s) to the provided repositories.
repo_contributors
repo_contributors(repo, include_admins = TRUE)
Character. Address of one or more repositories in owner/name format.
owner/name
Logical. If FALSE, usernames of users with Admin rights are excluded, defaults to TRUE.
FALSE
TRUE
A tibble.
# NOT RUN { repo_contributors("ghclass-test/test") # } # NOT RUN { # }
Run the code above in your browser using DataLab