powered by
repo_exists returns TRUE if the github repository exists. The function also prints a message if a repository has been renamed.
repo_exists
repo_exists(repo, strict = FALSE, verbose = TRUE)
Character. Address of repository in "owner/name" format.
Logical. Specifies whether renamed repositories are allowed.
Logical. Specifies if details on renamed repositories should be printed.
A logical vector
# NOT RUN { repo_exists(c("rundel/ghclass", "rundel/ghclass_fake")) # } # NOT RUN { # }
Run the code above in your browser using DataLab