repo_get_file: Low level function for retrieving a file from a GitHub Repository
Description
Low level function for retrieving a file from a GitHub Repository
Usage
repo_get_file(repo, path, branch = "master")
Arguments
repo
Character. Address of repository in owner/name format.
path
Characer. Path to the file within the repository.
branch
Character. Name of branch to use, defaults to "master".