Modify a file within a repository
repo_modify_file(
repo,
path,
pattern,
content,
method = c("replace", "before", "after"),
all = FALSE,
message = "Modified content",
branch = "master"
)Character. Address of repository in owner/name format.
Character. File's path within the repository.
Character. Regex pattern.
Character. Content to be added to the file.
Character. Should the content replace the matched pattern or be inserted before or after the match.
Character. Should all instances of the pattern be modified (TRUE) or just the first (FALSE).
Character. Commit message.
Character. Name of branch to use, defaults to "master".