powered by
action_add_badge() - Add a GitHub Actions badge to a file.
action_add_badge()
action_remove_badge() - Remove one or more GitHub Action badges from a file.
action_remove_badge()
action_add_badge( repo, workflow = NULL, where = "^.", line_padding = "\n\n\n", file = "README.md" )action_remove_badge(repo, workflow_pat = ".*?", file = "README.md")
action_remove_badge(repo, workflow_pat = ".*?", file = "README.md")
Both action_add_badge() and action_remove_badge() invisibly return a list containing the results of the relevant GitHub API call.
Character. Address of repository in owner/name format.
owner/name
Character. Name of the workflow.
Character. Regex pattern indicating where to insert the badge, defaults to the beginning of the target file.
Character. What text should be added after the badge.
Character. Target file to be modified, defaults to README.md.#'
README.md
Character. Name of the workflow to be removed, or a regex pattern that matches the workflow name.
if (FALSE) { action_add_badge("ghclass-test/hw1-team01") action_remove_badge("ghclass-test/hw1-team01") }
Run the code above in your browser using DataLab