View source: R/org_grade_assignment.R
| org_grade_assignment | R Documentation |
This is a higher level function that automates the common steps for setting up grading of an assignment:
Find repos matching a filter pattern in an organization
Clone all matched repos locally
Download GitHub Actions artifacts (e.g. rendered html, md files)
Report any missing artifacts
Create comment template files for each repo
org_grade_assignment(
path,
org,
repo_filter,
artifacts = character(),
comment_template = "",
key_repo = NULL
)
path |
Character. Root directory for the grading folder (created if it doesn't exist). |
org |
Character. Name of the GitHub organization. |
repo_filter |
Character. Regex pattern passed to |
artifacts |
Named character vector. Names are subfolder names, values are
regex patterns passed as |
comment_template |
Character. Template text used to populate each comment
markdown file. Defaults to |
key_repo |
Character. Optional repository address in |
An invisible list containing:
repos — character vector of matched repo addresses
cloned — result from local_repo_clone()
artifacts — named list of results from each action_artifact_download() call
comments — character vector of comment file paths created
key — result from cloning the key repo (if provided)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.