powered by
pages_enabled() - returns TRUE if a Pages site exists for the repo.
pages_enabled()
TRUE
pages_status() - returns more detailed information about a repo's Pages site.
pages_status()
pages_create() - creates a Pages site for the provided repos.
pages_create()
pages_delete() - deletes the Pages site for the provided repos.
pages_delete()
pages_enabled(repo)pages_status(repo)pages_create( repo, build_type = c("legacy", "workflow"), branch = "main", path = "/" )pages_delete(repo, prompt = TRUE)
pages_status(repo)
pages_create( repo, build_type = c("legacy", "workflow"), branch = "main", path = "/" )
pages_delete(repo, prompt = TRUE)
pages_enabled() returns a named logical vector - TRUE if a Pages site exists, FALSE otherwise.
FALSE
pages_status() returns a tibble containing details on Pages sites.
pages_create() & pages_delete() return an invisible list containing the API responses.
Character. Address of repositories in owner/name format.
owner/name
Character. Either "workflow" or "legacy" - the former uses GitHub actions to build and publish the site (requires a workflow file to achieve this).
"workflow"
"legacy"
Character. Repository branch to publish.
Character. Repository path to publish.
Logical. Should the user be prompted before deleting Pages sites. Default TRUE.
if (FALSE) { pages_enabled("rundel/ghclass") pages_status("rundel/ghclass") }
Run the code above in your browser using DataLab