Add a GitHub Actions badge
repo_add_badge(
repo,
workflow = NULL,
where = "^.",
line_padding = "\n\n\n",
file = "README.md"
)Character. Address of repository in owner/name format.
Character. Name of the workflow located in .github/workflows/.
Character. Regex pattern of where to insert the badge, defaults to the beginning of the README
Character. What should be added to the end of the link, defaults to sufficient new lines to add a blank line after the badge.
Character. Target file to be modified, defaults to README.md.